@@ -39,8 +39,6 @@
 #include "clock-utils.h"
 #include "clock-typebuiltins.h"
 
-#define CALENDAR_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CALENDAR_TYPE_WINDOW, CalendarWindowPrivate))
-
 #define KEY_LOCATIONS_EXPANDED      "expand-locations"
 
 enum {
@@ -64,7 +62,7 @@ struct _CalendarWindowPrivate {
 	GSettings  *settings;
 };
 
-G_DEFINE_TYPE (CalendarWindow, calendar_window, GTK_TYPE_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (CalendarWindow, calendar_window, GTK_TYPE_WINDOW)
 
 enum {
 	PROP_0,
@@ -206,7 +204,7 @@ create_hig_frame (CalendarWindow *calwin,
 	g_signal_connect (expander, "notify::expanded",
 			  G_CALLBACK (expand_collapse), vbox);
 
-	/* FIXME: this doesn't really work, since "add" does not 
+	/* FIXME: this doesn't really work, since "add" does not
 	 * get emitted for e.g. gtk_box_pack_start
 	 */
 	g_signal_connect (vbox, "add", G_CALLBACK (add_child), expander);
@@ -423,8 +421,6 @@ calendar_window_class_init (CalendarWindowClass *klass)
 
 	gobject_class->dispose = calendar_window_dispose;
 
-	g_type_class_add_private (klass, sizeof (CalendarWindowPrivate));
-
 	signals[EDIT_LOCATIONS] = g_signal_new ("edit-locations",
 						G_TYPE_FROM_CLASS (gobject_class),
 						G_SIGNAL_RUN_FIRST,
@@ -475,7 +471,7 @@ calendar_window_init (CalendarWindow *calwin)
 {
 	GtkWindow *window;
 
-	calwin->priv = CALENDAR_WINDOW_GET_PRIVATE (calwin);
+	calwin->priv = calendar_window_get_instance_private (calwin);
 
 	window = GTK_WINDOW (calwin);
 	gtk_window_set_type_hint (window, GDK_WINDOW_TYPE_HINT_DOCK);
