@@ -185,8 +185,6 @@ make_current_cb (gpointer data, GError *error)
                 g_signal_connect (dialog, "response",
                                   G_CALLBACK (gtk_widget_destroy), NULL);
                 gtk_window_present (GTK_WINDOW (dialog));
-
-                g_error_free (error);
         }
 }
 
@@ -706,6 +704,7 @@ update_weather_icon (ClockLocation *loc, WeatherInfo *info, gpointer data)
         if (surface) {
                 gtk_image_set_from_surface (GTK_IMAGE (priv->weather_icon), surface);
                 gtk_widget_set_margin_end (priv->weather_icon, 6);
+                cairo_surface_destroy (surface);
         }
 }
 
