@@ -3,7 +3,7 @@
  * Copyright (C) 2008 Novell, Inc.
  *
  * Authors: Vincent Untz <vuntz@gnome.org>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -17,11 +17,11 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
- * 
+ *
  * Some code is based on previous code in clock-location.c and on code from
  * tz.c (shipped with version <= 2.22.0). Those files were under the same
  * license, with those authors and copyrights:
- * 
+ *
  * clock-location.c:
  * ================
  * No header, but most of the work was done (AFAIK) by
@@ -36,7 +36,7 @@
  * Authors: Hans Petter Jansson <hpj@ximian.com>
  *	    additional functions by Erwann Chenede <erwann.chenede@sun.com>
  *	    reworked by Vincent Untz <vuntz@gnome.org>
- * 
+ *
  * Largely based on Michael Fulbright's work on Anaconda.
  */
 
@@ -76,8 +76,6 @@ static char *files_to_check[CHECK_NB] = {
 
 static GObject *systz_singleton = NULL;
 
-G_DEFINE_TYPE (SystemTimezone, system_timezone, G_TYPE_OBJECT)
-
 typedef struct {
         char *tz;
         char *env_tz;
@@ -89,6 +87,8 @@ enum {
 	LAST_SIGNAL
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (SystemTimezone, system_timezone, G_TYPE_OBJECT)
+
 static guint system_timezone_signals[LAST_SIGNAL] = { 0 };
 
 static GObject *system_timezone_constructor (GType                  type,
@@ -103,8 +103,6 @@ static void system_timezone_monitor_changed (GFileMonitor *handle,
                                              gpointer user_data);
 static char *system_timezone_find (void);
 
-#define PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SYSTEM_TIMEZONE_TYPE, SystemTimezonePrivate))
-
 SystemTimezone *
 system_timezone_new (void)
 {
@@ -118,7 +116,7 @@ system_timezone_get (SystemTimezone *systz)
 
         g_return_val_if_fail (IS_SYSTEM_TIMEZONE (systz), NULL);
 
-        priv = PRIVATE (systz);
+        priv = system_timezone_get_instance_private (systz);
         return priv->tz;
 }
 
@@ -129,7 +127,7 @@ system_timezone_get_env (SystemTimezone *systz)
 
         g_return_val_if_fail (IS_SYSTEM_TIMEZONE (systz), NULL);
 
-        priv = PRIVATE (systz);
+        priv = system_timezone_get_instance_private (systz);
         return priv->env_tz;
 }
 
@@ -149,19 +147,18 @@ system_timezone_class_init (SystemTimezoneClass *class)
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
-
-        g_type_class_add_private (class, sizeof (SystemTimezonePrivate));
 }
 
 static void
 system_timezone_init (SystemTimezone *systz)
 {
         int i;
-        SystemTimezonePrivate *priv = PRIVATE (systz);
+        SystemTimezonePrivate *priv;
+        priv = system_timezone_get_instance_private (systz);
 
         priv->tz = NULL;
         priv->env_tz = NULL;
-        for (i = 0; i < CHECK_NB; i++) 
+        for (i = 0; i < CHECK_NB; i++)
                 priv->monitors[i] = NULL;
 }
 
@@ -171,6 +168,7 @@ system_timezone_constructor (GType                  type,
                              GObjectConstructParam *construct_properties)
 {
         GObject *obj;
+        SystemTimezone *systz;
         SystemTimezonePrivate *priv;
         int i;
 
@@ -183,7 +181,8 @@ system_timezone_constructor (GType                  type,
                                                 n_construct_properties,
                                                 construct_properties);
 
-        priv = PRIVATE (obj);
+        systz = SYSTEM_TIMEZONE (obj);
+        priv = system_timezone_get_instance_private (systz);
 
         priv->tz = system_timezone_find ();
 
@@ -215,7 +214,7 @@ system_timezone_constructor (GType                  type,
 
                 if (priv->monitors[i])
                         g_signal_connect (G_OBJECT (priv->monitors[i]),
-                                          "changed", 
+                                          "changed",
                                           G_CALLBACK (system_timezone_monitor_changed),
                                           obj);
         }
@@ -229,7 +228,11 @@ static void
 system_timezone_finalize (GObject *obj)
 {
         int i;
-        SystemTimezonePrivate *priv = PRIVATE (obj);
+        SystemTimezone *systz;
+        SystemTimezonePrivate *priv;
+
+        systz = SYSTEM_TIMEZONE (obj);
+        priv = system_timezone_get_instance_private (systz);
 
         if (priv->tz) {
                 g_free (priv->tz);
@@ -261,7 +264,8 @@ system_timezone_monitor_changed (GFileMonitor *handle,
                                  GFileMonitorEvent event,
                                  gpointer user_data)
 {
-        SystemTimezonePrivate *priv = PRIVATE (user_data);
+        SystemTimezonePrivate *priv;
+        priv = system_timezone_get_instance_private (user_data);
         char *new_tz;
 
         if (event != G_FILE_MONITOR_EVENT_CHANGED &&
@@ -448,7 +452,7 @@ system_timezone_write_key_file (const char  *filename,
         gboolean   replaced;
         gboolean   retval;
         int        n;
-        
+
         if (!g_file_test (filename, G_FILE_TEST_IS_REGULAR))
                 return TRUE;
 
