@@ -66,7 +66,7 @@ struct _NaTrayAppletPrivate
 #endif
 };
 
-G_DEFINE_TYPE (NaTrayApplet, na_tray_applet, PANEL_TYPE_APPLET)
+G_DEFINE_TYPE_WITH_PRIVATE (NaTrayApplet, na_tray_applet, PANEL_TYPE_APPLET)
 
 static void (*parent_class_realize) (GtkWidget *widget);
 static void (*parent_class_style_updated) (GtkWidget *widget);
@@ -178,20 +178,20 @@ na_preferences_dialog_response (NaTrayApplet *applet,
 
 static void
 ensure_prefs_window_is_created (NaTrayApplet *applet)
-{  
+{
   if (applet->priv->dialog)
     return;
 
   applet->priv->dialog = g_new0 (NAPreferencesDialog, 1);
-  
+
   applet->priv->dialog->preferences_dialog = GTK_WIDGET (gtk_builder_get_object (applet->priv->builder, "notification_area_preferences_dialog"));
 
   gtk_window_set_icon_name (GTK_WINDOW (applet->priv->dialog->preferences_dialog), NOTIFICATION_AREA_ICON);
-  
+
   applet->priv->dialog->min_icon_size_spin = GTK_WIDGET (gtk_builder_get_object (applet->priv->builder, "min_icon_size_spin"));
   g_return_if_fail (applet->priv->dialog->min_icon_size_spin != NULL);
-  
-  gtk_spin_button_set_range (GTK_SPIN_BUTTON (applet->priv->dialog->min_icon_size_spin), 7, 100);
+
+  gtk_spin_button_set_range (GTK_SPIN_BUTTON (applet->priv->dialog->min_icon_size_spin), 7, 130);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (applet->priv->dialog->min_icon_size_spin), applet->priv->min_icon_size);
 
   g_signal_connect_swapped (applet->priv->dialog->min_icon_size_spin, "value_changed",
@@ -280,7 +280,7 @@ static void about_cb(GtkAction* action, NaTrayApplet* applet)
 		"copyright", _("Copyright \xc2\xa9 2002 Red Hat, Inc.\n"
 		               "Copyright \xc2\xa9 2003-2006 Vincent Untz\n"
 		               "Copyright \xc2\xa9 2011 Perberos\n"
-		               "Copyright \xc2\xa9 2012-2019 MATE developers"),
+		               "Copyright \xc2\xa9 2012-2020 MATE developers"),
 		"documenters", documenters,
 		"logo-icon-name", NOTIFICATION_AREA_ICON,
 		"translator-credits", _("translator-credits"),
@@ -460,8 +460,6 @@ na_tray_applet_class_init (NaTrayAppletClass *class)
                             0, G_MAXINT, 0,
                             G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
-  g_type_class_add_private (class, sizeof (NaTrayAppletPrivate));
-
   gtk_widget_class_set_css_name (widget_class, "na-tray-applet");
 }
 
@@ -471,8 +469,7 @@ na_tray_applet_init (NaTrayApplet *applet)
   MatePanelAppletOrient orient;
   AtkObject *atko;
 
-  applet->priv = G_TYPE_INSTANCE_GET_PRIVATE (applet, NA_TYPE_TRAY_APPLET,
-                                              NaTrayAppletPrivate);
+  applet->priv = na_tray_applet_get_instance_private (applet);
 
 #ifdef PROVIDE_WATCHER_SERVICE
   applet->priv->sn_watcher = sn_watcher_service_ref ();
