@@ -15,9 +15,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
+
+#ifndef HAVE_X11
+#error file should only be built when HAVE_X11 is enabled
+#endif
+
 #include <gtk/gtk.h>
 
-#if GTK_CHECK_VERSION (3, 18, 0)
 #include "panel-plug-private.h"
 
 struct _PanelPlug
@@ -83,9 +88,7 @@ panel_plug_class_init (PanelPlugClass *plug_class)
   widget_class->draw = panel_plug_draw;
   widget_class->realize = panel_plug_realize;
 
-#if GTK_CHECK_VERSION (3, 20, 0)
   gtk_widget_class_set_css_name (widget_class, "PanelApplet");
-#endif
 }
 
 static void
@@ -99,4 +102,3 @@ panel_plug_new (void)
 {
   return g_object_new (PANEL_TYPE_PLUG, NULL);
 }
-#endif
