@@ -31,13 +31,12 @@
 #include "panel-applet-frame-dbus.h"
 #include "panel-applets-manager-dbus.h"
 
-G_DEFINE_TYPE_WITH_CODE (MatePanelAppletsManagerDBus,
-			 mate_panel_applets_manager_dbus,
-			 PANEL_TYPE_APPLETS_MANAGER,
-			 g_io_extension_point_implement (MATE_PANEL_APPLETS_MANAGER_EXTENSION_POINT_NAME,
-							 g_define_type_id,
-							 "dbus",
-							 10))
+#ifdef HAVE_X11
+#include "gdk/gdkx.h"
+#endif
+#ifdef HAVE_WAYLAND
+#include "gdk/gdkwayland.h"
+#endif
 
 struct _MatePanelAppletsManagerDBusPrivate
 {
@@ -45,7 +44,18 @@ struct _MatePanelAppletsManagerDBusPrivate
 	GList      *monitors;
 };
 
+G_DEFINE_TYPE_WITH_CODE (MatePanelAppletsManagerDBus,
+			 mate_panel_applets_manager_dbus,
+			 PANEL_TYPE_APPLETS_MANAGER,
+			 G_ADD_PRIVATE(MatePanelAppletsManagerDBus)
+			 g_io_extension_point_implement (MATE_PANEL_APPLETS_MANAGER_EXTENSION_POINT_NAME,
+							 g_define_type_id,
+							 "dbus",
+							 10))
+
 typedef gint (* ActivateAppletFunc) (void);
+typedef GtkWidget * (* GetAppletWidgetFunc) (const gchar *factory_id,
+                                             guint        uid);
 
 typedef struct _MatePanelAppletFactoryInfo {
 	gchar              *id;
@@ -53,6 +63,7 @@ typedef struct _MatePanelAppletFactoryInfo {
 	gboolean            in_process;
 	GModule            *module;
 	ActivateAppletFunc  activate_applet;
+	GetAppletWidgetFunc get_applet_widget;
 	guint               n_applets;
 
 	gchar              *srcdir;
@@ -93,6 +104,9 @@ _mate_panel_applets_manager_get_applet_info (GKeyFile    *applet_file,
 	char             *comment;
 	char             *icon;
 	char            **old_ids;
+	char            **supported_platforms;
+	gboolean          x11_supported;
+	gboolean          wayland_supported;
 
 	iid = g_strdup_printf ("%s::%s", factory_id, group);
 	name = g_key_file_get_locale_string (applet_file, group,
@@ -104,13 +118,40 @@ _mate_panel_applets_manager_get_applet_info (GKeyFile    *applet_file,
 	old_ids = g_key_file_get_string_list (applet_file, group,
 					      "MateComponentId", NULL, NULL);
 
-	info = mate_panel_applet_info_new (iid, name, comment, icon, (const char **) old_ids);
+	supported_platforms = g_key_file_get_string_list (applet_file, group,
+							  "Platforms", NULL, NULL);
+	if (supported_platforms == NULL) {
+		// If supported platforms are not specified, assume all are supported
+		x11_supported = TRUE;
+		wayland_supported = TRUE;
+	} else {
+		int len, i;
+
+		x11_supported = FALSE;
+		wayland_supported = FALSE;
+		len = g_strv_length ((gchar **) supported_platforms);
+		for (i = 0; i < len; i++) {
+			if (g_strcmp0 (supported_platforms[i], "X11") == 0) {
+				x11_supported = TRUE;
+			} else if (g_strcmp0 (supported_platforms[i], "Wayland") == 0) {
+				wayland_supported = TRUE;
+			} else {
+				g_warning ("Unknown platform in %s applet: %s. "
+					   "Valid platforms are X11 and Wayland",
+					   name, supported_platforms[i]);
+			}
+		}
+	}
+
+	info = mate_panel_applet_info_new (iid, name, comment, icon, (const char **) old_ids,
+					   x11_supported, wayland_supported);
 
 	g_free (iid);
 	g_free (name);
 	g_free (comment);
 	g_free (icon);
 	g_strfreev (old_ids);
+	g_strfreev (supported_platforms);
 
 	return info;
 }
@@ -120,6 +161,7 @@ mate_panel_applets_manager_get_applet_factory_info_from_file (const gchar *filen
 {
 	MatePanelAppletFactoryInfo *info;
 	GKeyFile               *applet_file;
+	const char             *lib_prefix;
 	gchar                 **groups;
 	gsize                   n_groups;
 	gint                    i;
@@ -159,6 +201,16 @@ mate_panel_applets_manager_get_applet_factory_info_from_file (const gchar *filen
 
 			return NULL;
 		}
+		lib_prefix = g_getenv ("MATE_PANEL_APPLET_LIB_PREFIX");
+		if (lib_prefix && g_strcmp0 (lib_prefix, "") != 0) {
+			char *location;
+			int location_len = strlen (lib_prefix) + strlen (info->location) + 1;
+			location = g_strnfill (location_len, 0);
+			g_strlcat (location, lib_prefix, location_len);
+			g_strlcat (location, info->location, location_len);
+			g_free (info->location);
+			info->location = location;
+		}
 	}
 
 	info->has_old_ids = FALSE;
@@ -394,12 +446,31 @@ mate_panel_applets_manager_dbus_factory_activate (MatePanelAppletsManager *manag
 					     const gchar         *iid)
 {
 	MatePanelAppletFactoryInfo *info;
+	MatePanelAppletInfo    *applet_info;
 	ActivateAppletFunc      activate_applet;
+	GetAppletWidgetFunc     get_applet_widget;
 
 	info = get_applet_factory_info (manager, iid);
 	if (!info)
 		return FALSE;
 
+	applet_info = MATE_PANEL_APPLETS_MANAGER_GET_CLASS (manager)->get_applet_info (manager, iid);
+	g_return_val_if_fail (applet_info, FALSE);
+#ifdef HAVE_X11
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()) &&
+		!mate_panel_applet_info_get_x11_supported (applet_info)) {
+		g_warning ("Failed to load %p, because it does not support X11", iid);
+		return FALSE;
+	}
+#endif
+#ifdef HAVE_WAYLAND
+	if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()) &&
+		!mate_panel_applet_info_get_wayland_supported (applet_info)) {
+		g_warning ("Failed to load %p, because it does not support Wayland", iid);
+		return FALSE;
+	}
+#endif
+
 	/* Out-of-process applets are activated by the session bus */
 	if (!info->in_process)
 		return TRUE;
@@ -434,6 +505,15 @@ mate_panel_applets_manager_dbus_factory_activate (MatePanelAppletsManager *manag
 		return FALSE;
 	}
 
+	if (!g_module_symbol (info->module, "mate_panel_applet_get_applet_widget", (gpointer *) &get_applet_widget)) {
+		/* FIXME: use a GError? */
+		g_warning ("Failed to load applet %s: %s", iid, g_module_error ());
+		g_module_close (info->module);
+		info->module = NULL;
+
+		return FALSE;
+	}
+
 	/* Activate the applet */
 	if (activate_applet () != 0) {
 		/* FIXME: use a GError? */
@@ -444,6 +524,7 @@ mate_panel_applets_manager_dbus_factory_activate (MatePanelAppletsManager *manag
 		return FALSE;
 	}
 	info->activate_applet = activate_applet;
+	info->get_applet_widget = get_applet_widget;
 
 	info->n_applets = 1;
 
@@ -550,6 +631,20 @@ mate_panel_applets_manager_dbus_load_applet (MatePanelAppletsManager         *ma
 	return mate_panel_applet_frame_dbus_load (iid, frame_act);
 }
 
+static GtkWidget *
+mate_panel_applets_manager_dbus_get_applet_widget (MatePanelAppletsManager *manager,
+                                              const gchar         *iid,
+                                              guint                uid)
+{
+	MatePanelAppletFactoryInfo *info;
+
+	info = get_applet_factory_info (manager, iid);
+	if (!info)
+		return NULL;
+
+	return info->get_applet_widget (info->id, uid);
+}
+
 static void
 mate_panel_applets_manager_dbus_finalize (GObject *object)
 {
@@ -572,9 +667,7 @@ mate_panel_applets_manager_dbus_finalize (GObject *object)
 static void
 mate_panel_applets_manager_dbus_init (MatePanelAppletsManagerDBus *manager)
 {
-	manager->priv = G_TYPE_INSTANCE_GET_PRIVATE (manager,
-						     PANEL_TYPE_APPLETS_MANAGER_DBUS,
-						     MatePanelAppletsManagerDBusPrivate);
+	manager->priv = mate_panel_applets_manager_dbus_get_instance_private (manager);
 
 	manager->priv->applet_factories = g_hash_table_new_full (g_str_hash,
 								 g_str_equal,
@@ -598,6 +691,5 @@ mate_panel_applets_manager_dbus_class_init (MatePanelAppletsManagerDBusClass *cl
 	manager_class->get_applet_info = mate_panel_applets_manager_dbus_get_applet_info;
 	manager_class->get_applet_info_from_old_id = mate_panel_applets_manager_dbus_get_applet_info_from_old_id;
 	manager_class->load_applet = mate_panel_applets_manager_dbus_load_applet;
-
-	g_type_class_add_private (class, sizeof (MatePanelAppletsManagerDBusPrivate));
+	manager_class->get_applet_widget = mate_panel_applets_manager_dbus_get_applet_widget;
 }
