@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *
  * Authors:
  *	Vincent Untz <vuntz@gnome.org>
@@ -35,6 +35,25 @@ extern "C" {
 
 void panel_gtk_file_chooser_add_image_preview (GtkFileChooser *chooser);
 
+GtkWidget* panel_dialog_add_button (GtkDialog   *dialog,
+				    const gchar *button_text,
+				    const gchar *icon_name,
+				          gint   response_id);
+
+GtkWidget* panel_file_chooser_dialog_new (const gchar          *title,
+					  GtkWindow            *parent,
+					  GtkFileChooserAction  action,
+					  const gchar          *first_button_text,
+					  ...);
+
+GtkWidget* panel_image_menu_item_new_from_icon (const gchar *icon_name,
+						const gchar *label_name);
+
+GtkWidget* panel_image_menu_item_new_from_gicon (GIcon       *gicon,
+						 const gchar *label_name);
+
+GtkWidget* panel_check_menu_item_new (GtkWidget *widget_check);
+
 #ifdef __cplusplus
 }
 #endif
