@@ -13,7 +13,6 @@
 #include <sys/wait.h>
 
 #include <glib/gi18n.h>
-#include <gdk/gdkx.h>
 
 #include <libegg/eggdesktopfile.h>
 #include <libegg/eggsmclient.h>
@@ -24,16 +23,23 @@
 #include "panel-profile.h"
 #include "panel-config-global.h"
 #include "panel-shell.h"
-#include "panel-multiscreen.h"
+#include "panel-multimonitor.h"
 #include "panel-session.h"
 #include "panel-schemas.h"
 #include "panel-stock-icons.h"
-#include "panel-action-protocol.h"
 #include "panel-lockdown.h"
 #include "panel-icon-names.h"
 #include "panel-reset.h"
 #include "panel-run-dialog.h"
+
+#ifdef HAVE_X11
+#include "panel-action-protocol.h"
 #include "xstuff.h"
+#endif
+
+#ifdef HAVE_WAYLAND
+#include "wayland-backend.h"
+#endif
 
 /* globals */
 GSList *panels = NULL;
@@ -135,7 +141,7 @@ main (int argc, char **argv)
 	if (run_dialog == TRUE)
 	{
 		panel_init_stock_icons_and_items ();
-		panel_multiscreen_init ();
+		panel_multimonitor_init ();
 		panel_global_config_load ();
 		panel_lockdown_init ();
 		panel_profile_settings_load ();
@@ -158,8 +164,14 @@ main (int argc, char **argv)
 		return -1;
 	}
 
-	panel_action_protocol_init ();
-	panel_multiscreen_init ();
+	display = gdk_display_get_default ();
+
+#ifdef HAVE_X11
+	if (GDK_IS_X11_DISPLAY (display))
+		panel_action_protocol_init ();
+#endif
+
+	panel_multimonitor_init ();
 	panel_init_stock_icons_and_items ();
 
 	panel_global_config_load ();
@@ -171,11 +183,27 @@ main (int argc, char **argv)
 	                 (GFunc)panel_widget_add_forbidden,
 	                 NULL);
 
-	xstuff_init ();
+	gboolean found_backend = FALSE;
+
+#ifdef HAVE_WAYLAND
+	if (GDK_IS_WAYLAND_DISPLAY (display)) {
+		found_backend = TRUE;
+	}
+#endif
+
+#ifdef HAVE_X11
+	if (GDK_IS_X11_DISPLAY (display)) {
+		xstuff_init ();
+		found_backend = TRUE;
+	}
+#endif
+
+	if (!found_backend) {
+		g_error("GDK platform not supported");
+	}
 
 	/* Flush to make sure our struts are seen by everyone starting
 	 * immediate after (eg, the caja desktop). */
-	display = gdk_display_get_default ();
 	gdk_display_flush (display);
 
 	/* Do this at the end, to be sure that we're really ready when
