@@ -34,6 +34,7 @@
 #include <libpanel-util/panel-keyfile.h>
 #include <libpanel-util/panel-show.h>
 #include <libpanel-util/panel-xdg.h>
+#include <libpanel-util/panel-gtk.h>
 
 #include "panel-ditem-editor.h"
 #include "panel-icon-names.h"
@@ -167,9 +168,7 @@ enum {
 
 static guint ditem_edit_signals[LAST_SIGNAL] = { 0 };
 
-#define PANEL_DITEM_EDITOR_GET_PRIVATE(o)  (PANEL_DITEM_EDITOR (o)->priv)
-
-G_DEFINE_TYPE (PanelDItemEditor, panel_ditem_editor, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE (PanelDItemEditor, panel_ditem_editor, GTK_TYPE_DIALOG)
 
 static void panel_ditem_editor_setup_ui (PanelDItemEditor *dialog);
 
@@ -380,9 +379,6 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 
 	gobject_class->dispose = panel_ditem_editor_dispose;
 
-	g_type_class_add_private (class,
-				  sizeof (PanelDItemEditorPrivate));
-
 	ditem_edit_signals[SAVED] =
 		g_signal_new ("saved",
 			      G_TYPE_FROM_CLASS (gobject_class),
@@ -648,24 +644,29 @@ panel_ditem_editor_make_ui (PanelDItemEditor *dialog)
 	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->comment_label),
 				       priv->comment_entry);
 
-	priv->help_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						   "gtk-help",
-						   GTK_RESPONSE_HELP);
-	priv->revert_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						     "gtk-revert-to-saved",
-						     REVERT_BUTTON);
+	priv->help_button = panel_dialog_add_button (GTK_DIALOG (dialog),
+						     _("_Help"), "help-browser",
+						     GTK_RESPONSE_HELP);
+
+	priv->revert_button = panel_dialog_add_button (GTK_DIALOG (dialog),
+						       _("_Revert"), "document-revert",
+						       REVERT_BUTTON);
+
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
 					   REVERT_BUTTON,
 					   FALSE);
-	priv->close_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						    "gtk-close",
-						    GTK_RESPONSE_CLOSE);
-	priv->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						     "gtk-cancel",
-						     GTK_RESPONSE_CANCEL);
-	priv->ok_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						 "gtk-ok",
-						 GTK_RESPONSE_OK);
+
+	priv->close_button = panel_dialog_add_button (GTK_DIALOG (dialog),
+						      _("_Close"), "window-close",
+						      GTK_RESPONSE_CLOSE);
+
+	priv->cancel_button = panel_dialog_add_button (GTK_DIALOG (dialog),
+						       _("_Cancel"), "process-stop",
+						       GTK_RESPONSE_CANCEL);
+
+	priv->ok_button = panel_dialog_add_button (GTK_DIALOG (dialog),
+						   _("_OK"), "gtk-ok",
+						   GTK_RESPONSE_OK);
 
 	/* FIXME: There needs to be a way to edit ALL keys/sections */
 }
@@ -1003,13 +1004,14 @@ command_browse_button_clicked (PanelDItemEditor *dialog)
 		return;
 	}
 
-	chooser = gtk_file_chooser_dialog_new ("", GTK_WINDOW (dialog),
-					       GTK_FILE_CHOOSER_ACTION_OPEN,
-					       "gtk-cancel",
-					       GTK_RESPONSE_CANCEL,
-					       "gtk-open",
-					       GTK_RESPONSE_ACCEPT,
-					       NULL);
+	chooser = panel_file_chooser_dialog_new ("", GTK_WINDOW (dialog),
+						 GTK_FILE_CHOOSER_ACTION_OPEN,
+						 "process-stop",
+						 GTK_RESPONSE_CANCEL,
+						 "document-open",
+						 GTK_RESPONSE_ACCEPT,
+						 NULL);
+
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (chooser), TRUE);
 
 	g_signal_connect (chooser, "response",
@@ -1111,9 +1113,7 @@ panel_ditem_editor_init (PanelDItemEditor *dialog)
 {
 	PanelDItemEditorPrivate *priv;
 
-	priv = G_TYPE_INSTANCE_GET_PRIVATE (dialog,
-					    PANEL_TYPE_DITEM_EDITOR,
-					    PanelDItemEditorPrivate);
+	priv = panel_ditem_editor_get_instance_private (dialog);
 
 	dialog->priv = priv;
 
