@@ -25,6 +25,12 @@
 #ifndef __PANEL_FORCE_QUIT_H__
 #define __PANEL_FORCE_QUIT_H__
 
+#ifdef PACKAGE_NAME // only check HAVE_X11 if config.h has been included
+#ifndef HAVE_X11
+#error file should only be included when HAVE_X11 is enabled
+#endif
+#endif
+
 #include <gdk/gdk.h>
 
 #ifdef __cplusplus
