@@ -28,7 +28,10 @@
 
 #include <glib.h>
 #include <gio/gio.h>
+
+#ifdef HAVE_X11
 #include <gdk/gdkx.h>
+#endif
 
 #include <libmate-desktop/mate-dconf.h>
 #include <libmate-desktop/mate-gsettings.h>
@@ -99,7 +102,12 @@ panel_layout_filename ()
 
     settings = g_settings_new (PANEL_SCHEMA);
     layout = g_settings_get_string (settings, PANEL_DEFAULT_LAYOUT);
-    filename = g_strdup_printf (PANEL_LAYOUTS_DIR "%s.layout", layout);
+    if (g_str_has_prefix (layout, "/")) {
+        filename = g_strdup (layout);
+    }
+    else {
+        filename = g_strdup_printf (PANEL_LAYOUTS_DIR "%s.layout", layout);
+    }
     g_free (layout);
     g_object_unref (settings);
 
@@ -161,10 +169,14 @@ panel_layout_append_group_helper (GKeyFile                  *keyfile,
         dir = "toplevels";
         type = PANEL_GSETTINGS_TOPLEVELS;
     }
-    if (g_strcmp0 (id_list_key, PANEL_OBJECT_ID_LIST_KEY) == 0) {
+    else if (g_strcmp0 (id_list_key, PANEL_OBJECT_ID_LIST_KEY) == 0) {
         dir = "objects";
         type = PANEL_GSETTINGS_OBJECTS;
     }
+    else {
+        g_critical ("Unknown key \"%s\"", id_list_key);
+	return FALSE;
+    }
 
     dconf_path = g_strdup_printf (PANEL_RESOURCE_PATH "/%s", dir);
     existing_ids = mate_dconf_list_subdirs (dconf_path, TRUE);
@@ -277,6 +289,36 @@ panel_layout_append_group_helper (GKeyFile                  *keyfile,
     return retval;
 }
 
+static void
+panel_layout_apply_minimal_default (int          set_screen_to,
+                                    const char  *schema,
+                                    const char  *path_prefix)
+{
+    const char *unique_id = "bottom";
+    char       *path = NULL;
+    GSettings  *settings = NULL;
+
+    path = g_strdup_printf ("%s%s/", path_prefix, unique_id);
+    settings = g_settings_new_with_path (schema, path);
+    g_return_if_fail(settings);
+    g_free (path);
+
+    g_settings_set_boolean(settings, "expand", TRUE);
+    g_settings_set_string(settings, "orientation", "bottom");
+    g_settings_set_int(settings, "size", 24);
+    g_settings_set_int(settings, "screen", 0);
+
+    GSettings *panel_settings;
+    panel_settings = g_settings_new (PANEL_SCHEMA);
+    g_return_if_fail(panel_settings);
+    mate_gsettings_append_strv (panel_settings,
+                                PANEL_TOPLEVEL_ID_LIST_KEY,
+                                unique_id);
+
+    g_object_unref (panel_settings);
+    g_object_unref (settings);
+}
+
 void
 panel_layout_apply_default_from_gkeyfile (GdkScreen *screen)
 {
@@ -287,7 +329,12 @@ panel_layout_apply_default_from_gkeyfile (GdkScreen *screen)
     GError      *error = NULL;
     int          i;
 
-    screen_n = gdk_x11_screen_get_screen_number (screen);
+    screen_n = 0;
+#ifdef HAVE_X11
+    if (GDK_IS_X11_SCREEN (screen))
+	screen_n = gdk_x11_screen_get_screen_number (screen);
+#endif // HAVE_11
+
     layout_file = panel_layout_filename();
 
     if (layout_file)
@@ -350,7 +397,9 @@ panel_layout_apply_default_from_gkeyfile (GdkScreen *screen)
     }
     else {
         g_warning ("Cant find the layout file!");
-        /* FIXME implement a fallback panel */
+        panel_layout_apply_minimal_default(screen_n,
+                                           PANEL_TOPLEVEL_SCHEMA,
+                                           PANEL_TOPLEVEL_PATH);
     }
 
     if (groups)
