@@ -1236,6 +1236,11 @@ panel_profile_prepare_object_with_id (PanelObjectType  object_type,
 	g_settings_set_int (settings, PANEL_OBJECT_POSITION_KEY, position);
 	g_settings_set_boolean (settings, PANEL_OBJECT_PANEL_RIGHT_STICK_KEY, right_stick);
 
+	/* Force writing the settings in order to reserve the object ID *now*,
+	 * so that a later call to panel_profile_find_new_id() won't find the same
+	 * one. */
+	g_settings_sync ();
+
 	g_free (settings_path);
 	g_object_unref (settings);
 
@@ -1476,7 +1481,7 @@ panel_profile_toplevel_id_list_notify (GSettings *settings,
 	toplevel_ids = mate_gsettings_strv_to_gslist ((const gchar **) toplevel_ids_strv);
 	toplevel_ids = panel_g_slist_make_unique (toplevel_ids,
 						  (GCompareFunc) g_strcmp0,
-						  FALSE);
+						  TRUE);
 	g_strfreev (toplevel_ids_strv);
 
 	existing_toplevels = NULL;
@@ -1507,7 +1512,7 @@ panel_profile_toplevel_id_list_notify (GSettings *settings,
 		g_idle_add (load_default_layout_idle, NULL);
 
 	g_slist_free (existing_toplevels);
-	g_slist_free (toplevel_ids);
+	g_slist_free_full (toplevel_ids, g_free);
 }
 
 static void
@@ -1520,7 +1525,7 @@ panel_profile_object_id_list_update (gchar **objects)
 	object_ids = mate_gsettings_strv_to_gslist ((const gchar **) objects);
 	object_ids = panel_g_slist_make_unique (object_ids,
 						(GCompareFunc) g_strcmp0,
-						FALSE);
+						TRUE);
 
 	existing_applets = mate_panel_applet_list_applets ();
 
@@ -1542,7 +1547,7 @@ panel_profile_object_id_list_update (gchar **objects)
 									  (PanelProfileDestroyFunc) panel_profile_destroy_object);
 
 	g_slist_free (sublist);
-	g_slist_free (object_ids);
+	g_slist_free_full (object_ids, g_free);
 
 	mate_panel_applet_load_queued_applets (FALSE);
 }
